==> jc-1.4.0.tar.gz: java/util/zip/GZIPInputStream.h <==
// public class java.util.zip.GZIPInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 936c41bc1cf521d2 java_util_zip_GZIPInputStream
// @dep_class 5602700a47802920 java_util_zip_InflaterInputStream

// header file dependencies
// @dep_header java_util_zip_InflaterInputStream

#include "java/util/zip/InflaterInputStream.h"

#ifndef _JC_java_util_zip_GZIPInputStream_H_
#define _JC_java_util_zip_GZIPInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_CRC32$object;

// Typedefs
typedef struct _jc_java_util_zip_GZIPInputStream$sub_refs	_jc_java_util_zip_GZIPInputStream$sub_refs;
typedef struct _jc_java_util_zip_GZIPInputStream$sub_nonrefs	_jc_java_util_zip_GZIPInputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_GZIPInputStream$refs	_jc_java_util_zip_GZIPInputStream$refs;
typedef struct _jc_java_util_zip_GZIPInputStream$nonrefs	_jc_java_util_zip_GZIPInputStream$nonrefs;
typedef struct _jc_java_util_zip_GZIPInputStream$object	_jc_java_util_zip_GZIPInputStream$object;

typedef struct _jc_java_util_zip_GZIPInputStream$fields_struct	_jc_java_util_zip_GZIPInputStream$fields_struct;
typedef const struct _jc_java_util_zip_GZIPInputStream$vmethods	_jc_java_util_zip_GZIPInputStream$vmethods;
typedef const struct _jc_java_util_zip_GZIPInputStream$vtable	_jc_java_util_zip_GZIPInputStream$vtable;
typedef const struct _jc_java_util_zip_GZIPInputStream$vtype	_jc_java_util_zip_GZIPInputStream$vtype;

// Class fields structure
struct _jc_java_util_zip_GZIPInputStream$fields_struct {
	jint	FCOMMENT;
	jint	FEXTRA;
	jint	FHCRC;
	jint	FNAME;
	jint	FTEXT;
	jint	GZIP__5fMAGIC;
};
extern _jc_java_util_zip_GZIPInputStream$fields_struct _jc_java_util_zip_GZIPInputStream$class_fields;

// Constructors
extern void _jc_java_util_zip_GZIPInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *, struct _jc_java_io_InputStream$object *);
extern void _jc_java_util_zip_GZIPInputStream$method$_init$cce795e7dffd722d(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *, struct _jc_java_io_InputStream$object *, jint);

// Virtual methods
extern void _jc_java_util_zip_GZIPInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *);
extern jint _jc_java_util_zip_GZIPInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_java_util_zip_GZIPInputStream$method$readFooter$94f938333ce0ddb6(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *);
extern void _jc_java_util_zip_GZIPInputStream$method$readHeader$315d703f8609c43e(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_GZIPInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_util_zip_GZIPInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_util_zip_GZIPInputStream$method_info$readFooter$94f938333ce0ddb6;
extern _jc_method _jc_java_util_zip_GZIPInputStream$method_info$readHeader$315d703f8609c43e;

// Virtual methods structure
struct _jc_java_util_zip_GZIPInputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*readFooter$94f938333ce0ddb6)(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *);
	void	(*readHeader$315d703f8609c43e)(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *);
};

// Vtable
struct _jc_java_util_zip_GZIPInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_java_util_zip_InflaterInputStream$vmethods	java_util_zip_InflaterInputStream;
	_jc_java_util_zip_GZIPInputStream$vmethods	java_util_zip_GZIPInputStream;
};

// Vtype
struct _jc_java_util_zip_GZIPInputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_GZIPInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_GZIPInputStream$sub_refs {
	struct _jc_java_util_zip_CRC32$object	*crc;
};

// Reference instance fields (object)
struct _jc_java_util_zip_GZIPInputStream$refs {
    _jc_java_util_zip_GZIPInputStream$sub_refs	java_util_zip_GZIPInputStream;
    _jc_java_util_zip_InflaterInputStream$sub_refs	java_util_zip_InflaterInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_GZIPInputStream$sub_nonrefs {
	jboolean	eos;
	jboolean	readGZIPHeader;
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_GZIPInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_java_util_zip_InflaterInputStream$sub_nonrefs	java_util_zip_InflaterInputStream;
    _jc_java_util_zip_GZIPInputStream$sub_nonrefs	java_util_zip_GZIPInputStream;
};

// Object instance structure
struct _jc_java_util_zip_GZIPInputStream$object {
	_jc_java_util_zip_GZIPInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_GZIPInputStream$vtype	*vtype;
	_jc_java_util_zip_GZIPInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_GZIPInputStream$vtype _jc_java_util_zip_GZIPInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_GZIPInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_GZIPInputStream$class_object;

#endif	/* _JC_java_util_zip_GZIPInputStream_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/GZIPInputStream.h <==
// public class java.util.zip.GZIPInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c51bfb23c49b4e67 java_util_zip_GZIPInputStream
// @dep_class 5602700a47802920 java_util_zip_InflaterInputStream

// header file dependencies
// @dep_header java_util_zip_InflaterInputStream

#include "java/util/zip/InflaterInputStream.h"

#ifndef _JC_java_util_zip_GZIPInputStream_H_
#define _JC_java_util_zip_GZIPInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_CRC32$object;

// Typedefs
typedef struct _jc_java_util_zip_GZIPInputStream$sub_refs	_jc_java_util_zip_GZIPInputStream$sub_refs;
typedef struct _jc_java_util_zip_GZIPInputStream$sub_nonrefs	_jc_java_util_zip_GZIPInputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_GZIPInputStream$refs	_jc_java_util_zip_GZIPInputStream$refs;
typedef struct _jc_java_util_zip_GZIPInputStream$nonrefs	_jc_java_util_zip_GZIPInputStream$nonrefs;
typedef struct _jc_java_util_zip_GZIPInputStream$object	_jc_java_util_zip_GZIPInputStream$object;

typedef struct _jc_java_util_zip_GZIPInputStream$fields_struct	_jc_java_util_zip_GZIPInputStream$fields_struct;
typedef const struct _jc_java_util_zip_GZIPInputStream$vmethods	_jc_java_util_zip_GZIPInputStream$vmethods;
typedef const struct _jc_java_util_zip_GZIPInputStream$vtable	_jc_java_util_zip_GZIPInputStream$vtable;
typedef const struct _jc_java_util_zip_GZIPInputStream$vtype	_jc_java_util_zip_GZIPInputStream$vtype;

// Class fields structure
struct _jc_java_util_zip_GZIPInputStream$fields_struct {
	jint	FCOMMENT;
	jint	FEXTRA;
	jint	FHCRC;
	jint	FNAME;
	jint	FTEXT;
	jint	GZIP__5fMAGIC;
};
extern _jc_java_util_zip_GZIPInputStream$fields_struct _jc_java_util_zip_GZIPInputStream$class_fields;

// Constructors
extern void _jc_java_util_zip_GZIPInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_GZIPInputStream$method$_init$cce795e7dffd722d(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *, struct _jc_java_io_InputStream$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_zip_GZIPInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_zip_GZIPInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_GZIPInputStream$method$readFooter$94f938333ce0ddb6(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_zip_GZIPInputStream$method$readHeader$315d703f8609c43e(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_GZIPInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_util_zip_GZIPInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_util_zip_GZIPInputStream$method_info$readFooter$94f938333ce0ddb6;
extern _jc_method _jc_java_util_zip_GZIPInputStream$method_info$readHeader$315d703f8609c43e;

// Virtual methods structure
struct _jc_java_util_zip_GZIPInputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*readFooter$94f938333ce0ddb6)(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *) _JC_JCNI_ATTR;
	void	(*readHeader$315d703f8609c43e)(_jc_env *, struct _jc_java_util_zip_GZIPInputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_zip_GZIPInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_java_util_zip_InflaterInputStream$vmethods	java_util_zip_InflaterInputStream;
	_jc_java_util_zip_GZIPInputStream$vmethods	java_util_zip_GZIPInputStream;
};

// Vtype
struct _jc_java_util_zip_GZIPInputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_GZIPInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_GZIPInputStream$sub_refs {
	struct _jc_java_util_zip_CRC32$object	*crc;
};

// Reference instance fields (object)
struct _jc_java_util_zip_GZIPInputStream$refs {
    _jc_java_util_zip_GZIPInputStream$sub_refs	java_util_zip_GZIPInputStream;
    _jc_java_util_zip_InflaterInputStream$sub_refs	java_util_zip_InflaterInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_GZIPInputStream$sub_nonrefs {
	jboolean	eos;
	jboolean	readGZIPHeader;
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_GZIPInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_java_util_zip_InflaterInputStream$sub_nonrefs	java_util_zip_InflaterInputStream;
    _jc_java_util_zip_GZIPInputStream$sub_nonrefs	java_util_zip_GZIPInputStream;
};

// Object instance structure
struct _jc_java_util_zip_GZIPInputStream$object {
	_jc_java_util_zip_GZIPInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_GZIPInputStream$vtype	*vtype;
	_jc_java_util_zip_GZIPInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_GZIPInputStream$vtype _jc_java_util_zip_GZIPInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_GZIPInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_GZIPInputStream$class_object;

#endif	/* _JC_java_util_zip_GZIPInputStream_H_ */
